==> rer.ufficiostampa-1.6.7-py3-none-any.whl: rer/ufficiostampa/subscriptions/catalog.py <==
# -*- coding: utf-8 -*-
from repoze.catalog.catalog import Catalog
from repoze.catalog.indexes.field import CatalogFieldIndex
from souper.interfaces import ICatalogFactory
from souper.soup import NodeAttributeIndexer
from zope.interface import implementer
from repoze.catalog.indexes.text import CatalogTextIndex
from souper.soup import NodeTextIndexer
from repoze.catalog.indexes.keyword import CatalogKeywordIndex

import logging

logger = logging.getLogger(__name__)


@implementer(ICatalogFactory)
class SubscriptionsSoupCatalogFactory(object):
    def __call__(self, context):
        catalog = Catalog()
        text_indexer = NodeTextIndexer(["name", "surname", "email"])
        catalog[u"text"] = CatalogTextIndex(text_indexer)
        email_indexer = NodeAttributeIndexer("email")
        catalog[u"email"] = CatalogFieldIndex(email_indexer)
        name_indexer = NodeAttributeIndexer("name")
        catalog[u"name"] = CatalogFieldIndex(name_indexer)
        surname_indexer = NodeAttributeIndexer("surname")
        catalog[u"surname"] = CatalogFieldIndex(surname_indexer)
        channels_indexer = NodeAttributeIndexer("channels")
        catalog[u"channels"] = CatalogKeywordIndex(channels_indexer)
        date_indexer = NodeAttributeIndexer("date")
        catalog[u"date"] = CatalogFieldIndex(date_indexer)
        newspaper_indexer = NodeAttributeIndexer("newspaper")
        catalog[u"newspaper"] = CatalogFieldIndex(newspaper_indexer)
        return catalog


@implementer(ICatalogFactory)
class SendHistorySoupCatalogFactory(object):
    def __call__(self, context):
        catalog = Catalog()
        channels_indexer = NodeAttributeIndexer("channels")
        catalog[u"channels"] = CatalogKeywordIndex(channels_indexer)
        date_indexer = NodeAttributeIndexer("date")
        catalog[u"date"] = CatalogFieldIndex(date_indexer)
        title_indexer = NodeAttributeIndexer("title")
        catalog[u"title"] = CatalogTextIndex(title_indexer)
        type_indexer = NodeAttributeIndexer("type")
        catalog[u"type"] = CatalogFieldIndex(type_indexer)
        return catalog

==> rer.ufficiostampa-2.0.1-py3-none-any.whl: rer/ufficiostampa/subscriptions/catalog.py <==
from repoze.catalog.catalog import Catalog
from repoze.catalog.indexes.field import CatalogFieldIndex
from repoze.catalog.indexes.keyword import CatalogKeywordIndex
from repoze.catalog.indexes.text import CatalogTextIndex
from souper.interfaces import ICatalogFactory
from souper.soup import NodeAttributeIndexer
from souper.soup import NodeTextIndexer
from zope.interface import implementer

import logging


logger = logging.getLogger(__name__)


@implementer(ICatalogFactory)
class SubscriptionsSoupCatalogFactory:
    def __call__(self, context):
        catalog = Catalog()
        text_indexer = NodeTextIndexer(["name", "surname", "email"])
        catalog["text"] = CatalogTextIndex(text_indexer)
        email_indexer = NodeAttributeIndexer("email")
        catalog["email"] = CatalogFieldIndex(email_indexer)
        name_indexer = NodeAttributeIndexer("name")
        catalog["name"] = CatalogFieldIndex(name_indexer)
        surname_indexer = NodeAttributeIndexer("surname")
        catalog["surname"] = CatalogFieldIndex(surname_indexer)
        channels_indexer = NodeAttributeIndexer("channels")
        catalog["channels"] = CatalogKeywordIndex(channels_indexer)
        date_indexer = NodeAttributeIndexer("date")
        catalog["date"] = CatalogFieldIndex(date_indexer)
        newspaper_indexer = NodeAttributeIndexer("newspaper")
        catalog["newspaper"] = CatalogFieldIndex(newspaper_indexer)
        return catalog


@implementer(ICatalogFactory)
class SendHistorySoupCatalogFactory:
    def __call__(self, context):
        catalog = Catalog()
        channels_indexer = NodeAttributeIndexer("channels")
        catalog["channels"] = CatalogKeywordIndex(channels_indexer)
        date_indexer = NodeAttributeIndexer("date")
        catalog["date"] = CatalogFieldIndex(date_indexer)
        title_indexer = NodeAttributeIndexer("title")
        catalog["title"] = CatalogTextIndex(title_indexer)
        type_indexer = NodeAttributeIndexer("type")
        catalog["type"] = CatalogFieldIndex(type_indexer)
        return catalog
